io3d package
============


Subpackages
-----------

.. toctree::


Module datareader
-----------------

.. automodule:: io3d.datareader
    :members:
    :undoc-members:
    :show-inheritance:


Module datawriter
-----------------

.. automodule:: io3d.datawriter
    :members:
    :undoc-members:
    :show-inheritance:

Module datasets
---------------

.. automodule:: io3d.datasets
    :members:
    :undoc-members:
    :show-inheritance:

Module dcmreaddata
------------------

.. automodule:: io3d.dcmreaddata
    :members:
    :undoc-members:
    :show-inheritance:

Module misc
-----------

.. automodule:: io3d.misc
    :members:
    :undoc-members:
    :show-inheritance:

Module datareaderqt
-------------------

.. automodule:: io3d.datareaderqt
    :members:
    :undoc-members:
    :show-inheritance:

